@@ -2,27 +2,48 @@
 #' Called exclusively by `atlas_` functions
 #' @noRd
 #' @keywords Internal
-check_atlas_inputs <- function(args){
+check_atlas_inputs <- function(args,
+                               error_call = rlang::caller_env()){
   if(!is.null(args$request)){
-    check_data_request(args$request)
-    update_data_request(args$request, args[-1])
+    if(!inherits(args$request, "data_request")){
+      c("Argument `.query` requires an object of type `data_request`.",
+        i = "You can create this object using `galah_call()`.",
+        i = "Did you specify the incorrect argument?") |>
+      cli::cli_abort(call = error_call)      
+    }    
+    request_obj <- args$request
   }else{
-    do.call(galah_call, args)
+    request_obj <- galah_call()
   }
+  added_arguments <- args[-1]
+  added_arguments <- added_arguments[!(purrr::map(added_arguments, is.null) |> unlist())]
+  if(length(added_arguments) > 0){
+    for(i in seq_along(added_arguments)){
+      request_obj <- do.call(update_request_object, 
+                             append(list(x = request_obj), added_arguments[i]))
+    }   
+  }
+  request_obj
 }
 
-#' Internal function to check for `data_request`s
+#' Internal function to lookup requests for authentication
+#' Note this is currently only called on `data_request` objects, and 
+#' then only before parsing
 #' @noRd
 #' @keywords Internal
-check_data_request <- function(request, error_call = caller_env()){
-  if(!inherits(request, "data_request")){
-    bullets <- c(
-      "Argument `.query` requires an object of type `data_request`.",
-      i = "You can create this object using `galah_call()`.",
-      i = "Did you specify the incorrect argument?"
-    )
-    abort(bullets, call = caller_env())      
-  }     
+check_authentication <- function(x){
+  if(is.null(x$authenticate) & 
+     isTRUE(potions::pour("user", "authenticate", .pkg = "galah")) & 
+     x$type %in% c("occurrences")){
+      x <- x |> authenticate()
+  }
+  atlas <- potions::pour("atlas", "region", .pkg = "galah")
+  if(atlas != "Australia" &
+     !is.null(x$authenticate)){
+      cli::cli_warn("Authentication not supported for atlas {atlas}: skipping")
+      x$authenticate <- NULL    
+  }
+  x
 }
 
 #' Internal function to check that the specified path exists, and if not,
@@ -51,65 +72,99 @@ check_directory <- function(x){
 #' Internal function to ensure a download file is given
 #' @noRd
 #' @keywords Internal
-check_download_filename <- function(file, ext = "zip"){
+check_download_filename <- function(file, 
+                                    ext = "zip"){
   if(!is.null(file)){ # is `file` present
-    expected_suffix <- paste0(".", ext, "$")
+    expected_suffix <- glue::glue(".{ext}$")
     if(!grepl(expected_suffix, file)){ # expected suffix is missing
       if(grepl("\\.[[:alpha:]]{2,4}$", file)){ # does it have a different suffix?
         file <- gsub("\\.[[:alpha:]]{2,4}$", 
                      sub("\\$$", "", expected_suffix), 
                      file) # replace
       }else{
-        file <- paste0(file, ".zip")  # append
+        file <- glue::glue("{file}.zip")
       }
     } # no else{}, as all good here
   }else{
-    current_time <- Sys.time() |> format("%Y-%m-%d_%H-%M-%S")
-    file <- paste0('data_', current_time, ".", ext)
+    current_time <- Sys.time() |> 
+      format("%Y-%m-%d_%H-%M-%S")
+    file <- glue::glue("data_{current_time}.{ext}")
   }
-  cache_directory <- pour("package", "directory", .pkg = "galah")
-    glue("{cache_directory}/{file}") |>
+  cache_directory <- potions::pour("package", "directory", 
+                                   .pkg = "galah")
+    glue::glue("{cache_directory}/{file}") |>
       as.character()
     # check_path()? # currently commented out in check.R
 }
 
 #' Subfunction to `check_login()`
-#' @importFrom jsonlite fromJSON
 #' @noRd
 #' @keywords Internal
-check_email <- function(.query){
+check_email <- function(.query, 
+                        call = rlang::caller_env()){
   if(is_gbif()){
-    email_text <- fromJSON(.query$body)$notificationAddresses
+    # actually we check the userpwd entry here
+    email_text <- .query$options$userpwd
+    if(email_text == ":"){
+      abort_email_missing(error_call = call)
+    }
   }else{
-    email_text <- url_parse(.query$url)$query$email
-  }
-  if(is.null(email_text)) {
-    abort_email_missing()
-  }else if(email_text == ""){
-    abort_email_missing()
+    # use purrr::pluck() to search for named slots
+    # base parsing captures `email_notify` and is therefore unrelable
+    email_text <- httr2::url_parse(.query$url) |>
+      purrr::pluck("query", "email")
+    # set criteria for missingness
+    email_text_missing <- if(is.null(email_text)){
+      TRUE
+    }else if(email_text == ""){
+      TRUE
+    }else{
+      FALSE
+    }
+    # authentication only acceptable alternative to email for ALA
+    if(is_ala()){
+      authentication_missing <- is.null(.query$authenticate)
+      if(email_text_missing & authentication_missing){
+        abort_email_missing(error_call = call)
+      }      
+    }else{
+      if(email_text_missing){
+        abort_email_missing(error_call = call)
+      }     
+    }
   }
   .query
 }
 
 #' Check files are filtered properly
-#' @importFrom rlang abort
 #' @noRd
 #' @keywords Internal
-check_files_filter <- function(x){
+check_files_filter <- function(x,
+                               error_call = rlang::caller_env()
+                               ){ 
   if(!(x$variable %in% c("media"))){
-    abort("Variable name must be a valid `type` accepted by `request_files()`.")
+    cli::cli_abort("Variable name must be a valid `type` accepted by `request_files()`.",
+                   call = error_call)
+  }
+  if(is.null(x$data)){
+    c("rhs must be a `tibble` containing media information.",
+      i = "at least, this tibble should contain `media_id` and `mime_type` columns.") |>
+    cli::cli_abort(call = error_call)    
   }
   if(!inherits(x$data, "data.frame")){
-    abort("rhs must be a `tibble` containing media information")
+    c("rhs must be a `tibble` containing media information.",
+      i = "at least, this tibble should contain `media_id` and `mime_type` columns.") |>
+    cli::cli_abort(call = error_call)
   }
 }
 
 #' check that objects passed within `galah_filter` have correct structure
-#' @importFrom rlang abort
 #' @noRd
 #' @keywords Internal
-check_filter_tibbles <- function(x){ # where x is a list of tibbles
-  syntax_valid <- lapply(x, function(a){
+check_filter_tibbles <- function(x, # where x is a list of tibbles
+                                 error_call = rlang::caller_env()
+                                 ){ 
+  syntax_valid <- purrr::map(x, \(a){
     if(length(colnames(a)) == 4){
       all(colnames(a) %in% c("variable", "logical", "value", "query"))
     }else{
@@ -119,22 +174,18 @@ check_filter_tibbles <- function(x){ # where x is a list of tibbles
     unlist() |>
     all()
   if(!syntax_valid){
-    abort("There was a problem with `filter`, did you use correct syntax?")
+    cli::cli_abort("There was a problem with `filter`, did you use correct syntax?",
+                   call = error_call)
   }
 }
 
 #' Internal function to check whether fields are valid
-#' @importFrom dplyr bind_rows
-#' @importFrom dplyr pull
-#' @importFrom glue glue_collapse
-#' @importFrom glue glue_data
-#' @importFrom httr2 url_parse
-#' @importFrom rlang format_error_bullets
 #' @noRd
 #' @keywords Internal
-check_fields <- function(.query) {
+check_fields <- function(.query,
+                         error_call = rlang::caller_env()) {
   
-  if(pour("package", "run_checks")){
+  if(potions::pour("package", "run_checks")){
     if(is_gbif()){
       if(.query$type == "data/occurrences"){
         check_result <- check_fields_gbif_predicates(.query)  
@@ -147,33 +198,42 @@ check_fields <- function(.query) {
 
     # error message
     if(any(!is.na(check_result))) {
-      returned_invalid <- tibble(
-        function_name = c("`galah_filter()`", "`galah_group_by()`"),
+      returned_invalid <- tibble::tibble(
+        function_name = c("`filter()`", "`group_by()`"),
         fields = check_result) |>
         tidyr::drop_na()
       
       glue_template <- "{returned_invalid$function_name}: {returned_invalid$fields}"
-      invalid_fields_message <- glue_data(returned_invalid, glue_template, .na = "")
+      invalid_fields_message <- glue::glue_data(returned_invalid, glue_template, .na = "")
       
       bullets <- c(
         "Can't use fields that don't exist.",
         i = "Use `search_all(fields)` to find a valid field ID.",
-        x = glue("Can't find field(s) in"),
-        glue("  ", format_error_bullets(invalid_fields_message))
+        x = glue::glue("Can't find field(s) in"),
+        glue::glue("  ", 
+                   rlang::format_error_bullets(invalid_fields_message),
+                   call = error_call)
       )
-      abort(bullets)
+      cli::cli_abort(bullets)
     }
   }
   .query
 }
 
 #' Check whether fields match those requested, and if not, inform the user
-#' @importFrom rlang warn
-#' @importFrom rlang caller_env
 #' @noRd
 #' @keywords Internal
-check_field_identities <- function(df, .query){
-  if(!is.null(.query$fields) & pour("package", "run_checks")){
+check_field_identities <- function(df, 
+                                   .query,
+                                   error_call = rlang::caller_env()){
+  if(!is.null(.query$fields) & 
+     potions::pour("package", "run_checks", .pkg = "galah") & 
+     potions::pour("atlas", "region", .pkg = "galah") %in% c("Australia", "Spain", "Sweden")
+     # NOTE: last line included because the remaining atlases use different 
+     # architecture which tends to mean queries are sent with non-DwC terms,
+     # but return DwC terms. This triggers warnings that are technically
+     # correct, but practically misleading.
+  ){
     # get basic info
     n_fields <- length(.query$fields)
     field_names <- colnames(df)
@@ -184,84 +244,99 @@ check_field_identities <- function(df, .query){
     if(any(missing_check)){
       missing_fields <- .query$fields[missing_check]
       names(missing_fields) <- rep("*", length(missing_fields))
-      bullets <- c("The following fields, requested in your query, were not downloaded:",
-                   missing_fields)
-      warn(bullets)
+      c("The following fields, requested in your query, were not downloaded:",
+        missing_fields) |>
+      cli::cli_warn(call = error_call)
     }
     # check for additions
     added_check <- !(field_names %in% .query$fields)
     if(any(added_check)){
       added_fields <- field_names[added_check]
-      names(added_fields) <- rep("*", length(added_fields))
-      bullets <- c("The following fields were downloaded, but weren't requested in your query:",
-                   added_fields)
-      warn(bullets)
+      # if authentication has occurred, remove `sensitive_` fields
+      if(!is.null(.query$request$request$authenticate)){
+        added_fields <- added_fields[!stringr::str_detect(added_fields, "^sensitive")]
+      }
+      # then, if any remain, warn
+      if(length(added_fields) > 0){
+        names(added_fields) <- rep("*", length(added_fields))
+        c("The following fields were downloaded, but weren't requested in your query:",
+          added_fields) |>
+          cli::cli_warn(call = error_call)
+      }
     }
   }
   df
 }
 
 #' sub-function to `check_fields()` for GBIF
-#' @importFrom jsonlite fromJSON
-#' @importFrom purrr pluck
 #' @noRd
 #' @keywords Internal
 check_fields_gbif_counts <- function(.query){
-  # set fields to check against
-  valid_fields <- .query[["metadata/fields"]]$id
-  valid_assertions <- .query[["metadata/assertions"]]$id
-  valid_any <- c(valid_fields, valid_assertions)
-  url <- url_parse(.query$url[1])
 
-  # get fields from url
-  skip_fields <- c("limit", "facet", "facetLimit",
-                   "taxonKey", "geometry", "geoDistance") # GBIF-specific fields
-  query_names <- names(url$query)
-  fields <- query_names[!(query_names %in% skip_fields)]
-  # check invalid fields
+  # First get filters
+  # set fields that can be queried using predicates or downloaded
+  valid_download_fields <- .query[["metadata/fields"]] |>
+    dplyr::filter(.data$download_field == TRUE) |>
+    dplyr::pull("id")
+  valid_assertions <- .query[["metadata/assertions"]]$id
+  valid_any <- c(valid_download_fields, valid_assertions)
+
+  # check for invalid fields in predicates
+  filter_vec <- unlist(.query$body$filter)
+  filter_keys <- stringr::str_detect(names(filter_vec), "key$")
   filter_invalid <- NA
-  if (length(fields) > 0) {
+  if(any(filter_keys)){
+    fields <- filter_vec[filter_keys] |>
+      snake_to_camel_case()
     if (!all(fields %in% valid_any)) {
       invalid_fields <- fields[!(fields %in% valid_any)]
-      filter_invalid <- glue_collapse(invalid_fields, sep = ", ")
+      filter_invalid <- glue::glue_collapse(invalid_fields, sep = ", ")
     }
   }
-  
-  # check for invalid facets
+
+  # then facets  
+  # first extract facets
   group_by_invalid <- NA
-  if(any(query_names == "facet")){
-    fields <- unlist(url$query[which(query_names == "facet")])
-    if (!all(fields %in% valid_any)) {
-      invalid_fields <- fields[!(fields %in% valid_any)]
-      group_by_invalid <- glue_collapse(invalid_fields, sep = ", ")
-    }
+  if(!is.null(.query$body$group_by)){
+    facets <- .query$body$group_by$name
+    # check for invalid facets
+    valid_search_fields <- .query[["metadata/fields"]] |>
+      dplyr::filter(.data$search_field == TRUE) |>
+      dplyr::pull("id")
+     if (!all(facets %in% valid_search_fields)) {
+       invalid_facets <- facets[!(facets %in% valid_search_fields)]
+       group_by_invalid <- glue::glue_collapse(invalid_facets, sep = ", ")
+     }
   }
   
   c(filter_invalid, group_by_invalid)
 }
 
 #' sub-function to `check_fields()` for GBIF
-#' @importFrom jsonlite fromJSON
-#' @importFrom purrr pluck
 #' @noRd
 #' @keywords Internal
 check_fields_gbif_predicates <- function(.query){
+  
   # set fields to check against
   valid_fields <- .query[["metadata/fields"]]$id
   valid_assertions <- .query[["metadata/assertions"]]$id
   valid_any <- c(valid_fields, valid_assertions) |>
     camel_to_snake_case() |>
     toupper()
+
   # extract fields
-  fields <- .query$body |> 
-    fromJSON() |>
-    pluck("predicate", "predicates", "key")
+  predicates <- .query |>
+    purrr::pluck("body", "filter") |>
+    unlist()
+  keys <- grepl(".key$", names(predicates))
+  fields <- predicates[keys]
+
   # check invalid
   filter_invalid <- NA
   if (length(fields) > 0) {
     if (!all(fields %in% valid_any)) {
       invalid_fields <- fields[!(fields %in% valid_any)]
-      filter_invalid <- glue_collapse(invalid_fields, sep = ", ")
+      filter_invalid <- glue::glue_collapse(invalid_fields, sep = ", ")
     }
   }
   c(filter_invalid, NA)
@@ -295,7 +370,7 @@ check_fields_la <- function(.query){
     if (length(filters) > 0) {
       if (!all(filters %in% valid_any)) {
         invalid_fields <- filters[!(filters %in% valid_any)]
-        filter_invalid <- glue_collapse(invalid_fields, sep = ", ")
+        filter_invalid <- glue::glue_collapse(invalid_fields, sep = ", ")
       }
     }
   }
@@ -303,9 +378,9 @@ check_fields_la <- function(.query){
   # galah_group_by fields check
   group_by_invalid <- NA
   if(inherits(.query$url, "data.frame")){
-    url <- url_parse(.query$url$url[1])
+    url <- httr2::url_parse(.query$url$url[1])
   }else{
-    url <- url_parse(.query$url[1])
+    url <- httr2::url_parse(.query$url[1])
   }
   queries <- url$query
   if (!is.null(queries$facets)) {
@@ -313,7 +388,7 @@ check_fields_la <- function(.query){
     if (length(facets) > 0) {
       if (!all(facets %in% valid_any)) {
         invalid_fields <- facets[!(facets %in% valid_any)]
-        group_by_invalid <- glue_collapse(invalid_fields, sep = ", ")
+        group_by_invalid <- glue::glue_collapse(invalid_fields, sep = ", ")
       }
     }
   }
@@ -323,8 +398,12 @@ check_fields_la <- function(.query){
 
 
 # If no args are supplied, set default columns returned as group = "basic"
+#' @param group supplied group names
+#' @param n number of non-group arguments given
+#' @noRd
+#' @keywords Internal
 check_groups <- function(group, n){
-  if(missing(group)){
+  if(is.null(group)){
     if(n < 1){
       "basic"
     }else{
@@ -344,66 +423,28 @@ check_groups <- function(group, n){
 #' function to replace search terms with identifiers via `search_taxa()`  
 #' @noRd
 #' @keywords Internal
-check_identifiers <- function(.query){
+check_identifiers <- function(.query,
+                              error_call = rlang::caller_env()){
+  # For GBIF, which uses predicates, we 'promote' taxonomic queries to 'predicates'
   if(is_gbif()){
-    if(.query$type %in% c("data/occurrences", "data/species")){
-      check_identifiers_gbif_predicates(.query)
-    }else{
-      check_identifiers_gbif(.query) # mainly for `data/occurrences-count` 
-    }
+    .query$body$identify <- .query$`metadata/taxa-single`
+    .query
+  # otherwise we replace "(`TAXON_PLACEHOLDER`)"
   }else{
-    check_identifiers_la(.query)
+    check_identifiers_la(.query, error_call)
   }
 }
-
-#' `check_identifiers()` for gbif
-#' @noRd
-#' @keywords Internal
-check_identifiers_gbif <- function(.query){
-  url <- url_parse(.query$url[1]) # FIXME: test if every >1 urls here
-  if(!is.null(url$query)){
-    metadata_lookup <-grepl("metadata/taxa", names(.query))
-    if(any(metadata_lookup)){
-      identifiers <- .query[[which(metadata_lookup)[1]]]
-      taxon_query <- as.list(identifiers$taxon_concept_id)
-      names(taxon_query) <- rep("taxonKey", length(taxon_query))
-      url$query <- c(taxon_query,  
-                     url$query[names(url$query) != "taxonKey"])
-      .query$url[1] <- url_build(url)
-    }
-  }
-  .query
-}
-
-#' `check_identifiers()` for gbif occurrences
-#' @noRd
-#' @keywords Internal
-check_identifiers_gbif_predicates <- function(.query){
-  if(!is.null(.query$body)){
-    metadata_lookup <-grepl("metadata/taxa", names(.query))
-    if(any(metadata_lookup)){
-      identifiers <- .query[[which(metadata_lookup)[1]]]
-      .query$body <- sub("`TAXON_PLACEHOLDER`", 
-                        identifiers$taxon_concept_id[1], 
-                        .query$body)
-    }
-  }
-  .query
-}
   
 #' `check_identifiers()` for living atlases 
-#' @importFrom httr2 url_build
-#' @importFrom httr2 url_parse
-#' @importFrom rlang abort
-#' @importFrom stringr str_replace_all
 #' @noRd
 #' @keywords Internal
-check_identifiers_la <- function(.query, error_call = caller_env()){
+check_identifiers_la <- function(.query, 
+                                 error_call = rlang::caller_env()){
   # FIXME: test if every >1 urls here
   if(inherits(.query$url, "data.frame")){
-    url <- url_parse(.query$url$url[1])
+    url <- httr2::url_parse(.query$url$url[1])
   }else{
-    url <- url_parse(.query$url[1]) 
+    url <- httr2::url_parse(.query$url[1]) 
   }
   queries <- url$query
   if(!is.null(queries$fq)){
@@ -414,18 +455,20 @@ check_identifiers_la <- function(.query, error_call = caller_env()){
         
         # End query early when no taxonomic search terms were matched
         if (nrow(identifiers) > 0 && !("taxon_concept_id" %in% colnames(identifiers))) {
-          abort("No valid taxonomic identifiers detected.", call = error_call)
+          cli::cli_abort("No valid taxonomic identifiers detected.",
+                         call = error_call)
         }
         
         taxa_ids <- build_taxa_query(identifiers$taxon_concept_id)
-        queries$fq <- str_replace_all(queries$fq, 
-                                      "\\(`TAXON_PLACEHOLDER`\\)", 
-                                      taxa_ids)
+        queries$fq <- stringr::str_replace_all(queries$fq, 
+                                               "\\(`TAXON_PLACEHOLDER`\\)", 
+                                               taxa_ids)
         url$query <- queries
-        .query$url[1] <- url_build(url)
+        .query$url[1] <- httr2::url_build(url)
       }else{
         # this only happens if there is a bug earlier in the code
-        abort("The query has a taxonomic placeholder, but no taxon search has been run.")
+        cli::cli_abort("The query has a taxonomic placeholder, but no taxon search has been run.",
+                       call = error_call)
       }
     }
   }else{
@@ -435,10 +478,11 @@ check_identifiers_la <- function(.query, error_call = caller_env()){
       if(any(metadata_lookup)){ 
         identifiers <- .query[[which(metadata_lookup)[1]]]
         taxa_id <- utils::URLencode(identifiers$taxon_concept_id[1],
-                             reserved = TRUE)
+                                    reserved = TRUE)
         .query$url[1] <- sub("%60TAXON_PLACEHOLDER%60", taxa_id, .query$url[1])
       }else{
-        abort("The query has a taxonomic placeholder, but no taxon search has been run.")
+        cli::cli_abort("The query has a taxonomic placeholder, but no taxon search has been run.",
+                       call = error_call)
       }
     }
   }
@@ -449,22 +493,24 @@ check_identifiers_la <- function(.query, error_call = caller_env()){
 #' Called by `compute()`
 #' @noRd
 #' @keywords Internal
-#' @importFrom rlang caller_env
-check_login <- function(.query, error_call = caller_env()) {
+check_login <- function(.query, 
+                        error_call = rlang::caller_env()) {
   # Check for valid email for occurrences or species queries for all providers
-  if(.query$type == "data/occurrences" | .query$type == "data/species"){
-    switch(pour("atlas", "region"), 
-           "United Kingdom" = {},
-           "Global" = {check_email(.query); check_password(.query)},
-           check_email(.query))
+  if(is_gbif()){
+    if(grepl("^data", .query$type)){
+      check_email(.query, call = error_call)
+      check_password(.query, call = error_call)
+    }
+  }else{
+    if(.query$type %in% c("data/occurrences", "data/species") & 
+      is.null(.query$request$authenticate) # i.e. only validate if authenticate = FALSE
+      ){
+      switch(potions::pour("atlas", "region"), 
+             "United Kingdom" = {},
+             check_email(.query, call = error_call))
+    }
   }
   .query
-  # ALA requires an API key
-  # } else if (pour("atlas", "acronym") == "ALA") {
-  #   if (is.null(.query$headers$`x-api-key`) | .query$headers$`x-api-key` == "") {
-  #     abort_api_key_missing()
-  #   }
-  # }  
 }
 
 #' Internal function to convert multi-value media fields to list-columns
@@ -491,19 +537,20 @@ check_media_cols <- function(.query){
 #' @param .query a `query` object
 #' @noRd
 #' @keywords Internal
-check_media_cols_present <- function(.query, error_call = caller_env()){
+check_media_cols_present <- function(.query, 
+                                     error_call = rlang::caller_env()){
   fields <- .query |>
-    pluck("url") |>
-    url_parse() |> 
-    pluck("query", "fields") |>
+    purrr::pluck("url") |>
+    httr2::url_parse() |> 
+    purrr::pluck("query", "fields") |>
     strsplit(",") |>
-    pluck(1)
+    purrr::pluck(1)
   fields_check <- image_fields() %in% fields
   if(!any(fields_check)){
-    abort(c("No media fields requested.",
-            i = "Use `select()` to specify which media fields are required.",
-            i = "Valid fields are 'images', 'videos' and 'sounds'."),
-          call = error_call)
+    c("No media fields requested.",
+      i = "Use `select()` to specify which media fields are required.",
+      i = "Valid fields are 'images', 'videos' and 'sounds'.") |>
+    cli::cli_abort(call = error_call)
   }else{
     image_fields()[fields_check]
   }
@@ -512,63 +559,61 @@ check_media_cols_present <- function(.query, error_call = caller_env()){
 #' Internal function called by `filter()` et al
 #' @noRd
 #' @keywords Internal
-check_named_input <- function(dots){
+check_named_input <- function(dots,
+                              error_call = rlang::caller_env()){
   name_length <- any(length(names(dots) > 0)) & any(names(dots) != "")
   if(name_length){
-    bullets <- c(
-      "We detected a named input.",
-      i = "This usually means that you've used `=` instead of `==`.")
-    abort(bullets)
+    c("We detected a named input.",
+      i = "This usually means that you've used `=` instead of `==`.") |>
+    cli::cli_abort(call = error_call)
   }
 }
 
 #' Check whether geolocate functions have >1 argument
-#' @importFrom rlang warn
 #' @noRd
 #' @keywords Internal
-check_n_inputs <- function(dots, error_call = caller_env()) {
+check_n_inputs <- function(dots, 
+                           error_call = rlang::caller_env()) {
   if(length(dots) > 1){
     n_geolocations <- length(dots)
-    bullets <- c(
-      "More than 1 spatial area provided.",
-      "*" = glue("Using first location, ignoring additional {n_geolocations - 1} location(s).")
-    )
-    warn(bullets, call = error_call)
+     c("More than 1 spatial area provided.",
+       "*" = "Using first location, ignoring additional {n_geolocations - 1} location(s).") |>
+    cli::cli_warn(call = error_call)
   }
 }
 
 #' Internal function to ensure correct data extracted from API for LA/GBIF
 #' It makes all calls consistent so we only need one queue checking function
-#' @importFrom stringr str_trim
 #' @noRd
 #' @keywords Internal
-check_occurrence_response <- function(.query){
+check_occurrence_response <- function(.query,
+                                      error_call = rlang::caller_env()){
   names(.query) <- camel_to_snake_case(names(.query))
   
   if (!is.null(.query$status_code)) {
     
     error_type <- sub("\\:.*", "", .query$message) |> 
-      str_trim()
+      stringr::str_trim()
     
     bullets <- c(
       "There was a problem with your query.",
-      "*" = glue("message: {.query$message}"))
+      "*" = glue::glue("message: {.query$message}"))
     
     switch(as.character(error_type),
-           "500" = {abort(bullets,
-                          call = caller_env())},
-           "403" = {abort(c(bullets,
-                          i = "Is the email you provided to `galah_config()` registered with the selected atlas?"),
-                          call = caller_env())},
-           "404" = {abort(c(bullets,
-                          i = "Is the email you provided to `galah_config()` registered with the selected atlas?"),
-                          call = caller_env())},
-           "504" = {abort(c(bullets,
-                          i = "This usually means that the selected API is down.",
-                          i = "If you continue to receive this error, please email support@ala.org.au"),
-                          call = caller_env())},
-           abort("Aborting for unknown reasons.", # FIXME
-                 call = caller_env()))
+           "500" = {cli::cli_abort(bullets,
+                                   call = error_call)},
+           "403" = {cli::cli_abort(c(bullets,
+                                     i = "Is the email you provided to `galah_config()` registered with the selected atlas?"),
+                                   call = error_call)},
+           "404" = {cli::cli_abort(c(bullets,
+                                     i = "Is the email you provided to `galah_config()` registered with the selected atlas?"),
+                                   call = error_call)},
+           "504" = {cli::cli_abort(c(bullets,
+                                     i = "This usually means that the selected API is down.",
+                                     i = "If you continue to receive this error, please email support@ala.org.au"),
+                                   call = error_call)},
+           cli::cli_abort("Aborting for unknown reasons.", # FIXME
+                          call = error_call))
   } else {
     if (.query$status %in% c("finished", # ALA
                             "SUCCEEDED") # GBIF
@@ -586,8 +631,7 @@ check_occurrence_response <- function(.query){
   }
   # convert `key` to `status_url`
   if(is.null(.query$status_url) & !is.null(.query$key)){
-    .query$status_url <- paste0("https://api.gbif.org/v1/occurrence/download/",
-                               .query$key)
+    .query$status_url <- glue::glue("https://api.gbif.org/v1/occurrence/download/{.query$key}")
   }
   # add `queue_size`
   if(is.null(.query$queue_size)){
@@ -600,7 +644,9 @@ check_occurrence_response <- function(.query){
 #' @noRd
 #' @keywords Internal
 check_occurrence_status <- function(.query){
-  list(url = .query$status_url) |>
+  list(type = "data/occurrences",
+       url = .query$status_url) |>
+    as_query() |>
     query_API() |>
     as.list() |>
     check_occurrence_response()
@@ -619,10 +665,10 @@ check_occurrence_status <- function(.query){
 #' @noRd
 #' @keywords Internal
 check_password <- function(.query, 
-                           error_call = caller_env()){
+                           call = rlang::caller_env()){
   if (.query$options$userpwd == ":") {
-    abort("GBIF requires a username and password to download occurrences or species.",
-          call = error_call)
+    cli::cli_abort("GBIF requires a username and password to download occurrences or species.",
+          call = call)
   }
 }
 
@@ -647,21 +693,19 @@ check_password <- function(.query,
 # }
 
 #' Internal function to check a supplied profile is valid
-#' @importFrom glue glue
-#' @importFrom rlang abort
 #' @noRd
 #' @keywords Internal
-check_profiles <- function(.query, error_call = caller_env()){
+check_profiles <- function(.query, 
+                           error_call = rlang::caller_env()){
   if(!inherits(.query$url, "data.frame")){
-    query <- url_parse(.query$url[1])$query
+    query <- httr2::url_parse(.query$url[1])$query
     if(!is.null(query$qualityProfile)){
       profile <- query$qualityProfile
-      if(!profile %in% .query[["metadata/profiles"]]$shortName){
-        bullets <- c(
-          "Unrecognised profile requested.",
+      if(!profile %in% .query[["metadata/profiles"]]$short_name){
+        c("Unrecognised profile requested.",
           i = "See `?show_all(profiles)` for valid profiles.",
-          x = glue("Can't find profile `{profile}` for specified atlas."))
-        abort(bullets, call = error_call)
+          x = "Can't find profile `{profile}` for specified atlas.") |>
+        cli::cli_abort(call = error_call)
       }else{
         .query
       }
@@ -674,28 +718,27 @@ check_profiles <- function(.query, error_call = caller_env()){
 }
 
 #' Internal function to check that a reason code is valid
-#' @importFrom glue glue
-#' @importFrom rlang abort
 #' @noRd
 #' @keywords Internal
-check_reason <- function(.query, error_call = caller_env()){
-  if(atlas_supports_reasons_api()) {
+check_reason <- function(.query, 
+                         error_call = rlang::caller_env()){
+  if(reasons_supported()) {
     if(.query$type %in% c("data/occurrences", "data/species")){
-      query <- url_parse(.query$url)$query
+      query <- httr2::url_parse(.query$url)$query
       if(is.null(query$reasonTypeId)){
-        bullets <- c("Missing a valid download reason.",
-                     i = "See `show_all(reasons)`.",
-                     i = "Use `galah_config(download_reason_id = ...)` to set a download reason.")
-        abort(bullets, call = error_call) 
+        c("Missing a valid download reason.",
+          i = "See `show_all(reasons)`.",
+          i = "Use `galah_config(download_reason_id = ...)` to set a download reason.") |>
+        cli::cli_abort(call = error_call) 
       }else{
         user_reason <- query$reasonTypeId
         valid_reasons <- .query[["metadata/reasons"]]$id
         if(!(user_reason %in% valid_reasons)){
-          bullets <- c(
+           c(
             "Invalid download reason ID.",
             i = "Use `show_all(reasons)` to see all valid reasons.",
-            x = glue("\"{user_reason}\" does not match an existing reason ID."))
-          abort(bullets, call = error_call)    
+            x = "\"{user_reason}\" does not match an existing reason ID.") |>
+          cli::cli_abort(call = error_call)    
         }
       }
     }
@@ -705,19 +748,17 @@ check_reason <- function(.query, error_call = caller_env()){
 
 #' Check that `select()` quosures can be parsed correctly
 #' NOTE: much of this content was previously in `parse_select()` (defunct)
-#' @importFrom dplyr all_of
-#' @importFrom dplyr filter
-#' @importFrom httr2 url_parse
-#' @importFrom httr2 url_build
-#' @importFrom rlang is_quosure
 #' @noRd
 #' @keywords Internal
-check_select <- function(.query){
-  if(any(names(.query) == "select")){
-    if(is_gbif()){
-      inform(c("skipping `select()`:",
-               i = "This function is not supported by the GBIF API v1"))
-    }else{
+check_select <- function(.query,
+                         error_call = rlang::caller_env()){
+  if(any(names(.query$request) == "select")){
+    if(!(is_gbif() & stringr::str_detect(.query$type, "^data"))){
+      # cli::cli({
+      #  cli::cli_text("Skipping `select()`.")
+      #  cli::cli_bullets(c(i = "This function is not supported by the GBIF occurrences downloads API v1."))
+     # })
+    # }else{
       # 1. build df to `select` from
       valid_fields <- .query[["metadata/fields"]]$id
       valid_assertions <- .query[["metadata/assertions"]]$id
@@ -727,29 +768,34 @@ check_select <- function(.query){
         as.data.frame()
 
       # 2. parse groups
-      group_initial <- .query$select$group
+      group_initial <- .query$request$select$group
       # new step to avoid calling `show_all_assertions()` internally
       group <- group_initial[group_initial != "assertions"]
       if(length(group) > 0){
-        group_cols <- lapply(group, preset_groups) |> 
+        group_cols <- purrr::map(group, preset_groups) |> 
           unlist()
-        group_names <- tidyselect::eval_select(all_of(group_cols), data = df) |> 
+        group_names <- tidyselect::eval_select(dplyr::all_of(group_cols), 
+                                               data = df) |> 
           names()
         # note: technically `group_names` and `group_cols` are identical
         # BUT `eval_select()` will fail if invalid columns are given
       }else{
         group_names <- NULL
       }
-      
+
       # 3. parse quosures to get list of field names
-      check_quosures <- lapply(.query$select, is_quosure) |>
-        unlist()
-      dots <- .query$select[check_quosures]
-      dot_names <- lapply(dots, function(a){
-        tidyselect::eval_select(a, data = df) |>
-          names()
-      }) |>
-        unlist()
+      if(length(.query$request$select$quosure) > 0){
+        dot_names <- purrr::map(.query$request$select$quosure, 
+                                function(a){
+                                  tidyselect::eval_select(a,
+                                                          data = df,
+                                                          error_call = error_call) |>
+                                    names()
+                                }) |>
+          unlist()
+      }else{
+        dot_names <- c()
+      }
 
       # 3a: set 'identifier' column name
       id_col <- default_columns()[1]
@@ -785,10 +831,10 @@ check_select <- function(.query){
       # having e.g. media columns _before_ `recordID` causes the download to fail 
       field_values <- unique(c(group_names, individual_cols))
       if(is.null(field_values)){
-        bullets <- c("No fields selected",
-                     i = "Please specify a valid set of fields in `select()`",
-                     i = "You can look up valid fields using `show_all(fields)`")
-        abort(bullets)
+        c("No fields selected",
+          i = "Please specify a valid set of fields in `select()`",
+          i = "You can look up valid fields using `show_all(fields)`") |>
+          cli::cli_abort(call = error_call)
       }
       if(any(field_values == id_col)){
         field_values <- c(id_col, field_values[field_values != id_col]) # recordID needs to be first
@@ -800,21 +846,21 @@ check_select <- function(.query){
         assertion_text <- "includeall"
       }else{
         if(any(is_assertion)){
-          assertion_text <- paste(field_values[is_assertion], collapse = ",")
+          assertion_text <- glue::glue_collapse(field_values[is_assertion], 
+                                                sep = ",")
         }else{
           assertion_text <- "none"
         }
       }
-      field_text <- paste(field_values[!is_assertion],
-                          collapse = ",")
+      field_text <- glue::glue_collapse(field_values[!is_assertion],
+                                        sep = ",")
       
-      # 7. replace `SELECT_PLACEHOLDER` with valid query
+      # 7. replace `SELECT_PLACEHOLDER` and `ASSERTIONS_PLACEHOLDER` with valid queries
       # located in .query$url in query/fields
-      url <- url_parse(.query$url) # note: this assumes a single url every time
+      url <- httr2::url_parse(.query$url) # note: this assumes a single url every time
       url$query$fields <- field_text
       url$query$qa <- assertion_text
-      .query$url <- url_build(url)
-      .query$select <- NULL
+      .query$url <- httr2::url_build(url)
     }
   }
   .query
@@ -823,13 +869,13 @@ check_select <- function(.query){
 #' Check for valid `type`
 #' @noRd
 #' @keywords Internal
-check_type_valid <- function(type, valid, error_call = caller_env()) {
+check_type_valid <- function(type, 
+                             valid,
+                             error_call = rlang::caller_env()) {
   if(!any(valid == type)){
-    bullets <- c(
-      glue("Unrecognised metadata requested."),
+    c("Unrecognised metadata requested.",
       i = "See `?show_all()` for a list of valid metadata types.",
-      x = glue("Can't find metadata type `{type}`.")
-    )
-    abort(bullets, call = error_call)   
+      x = "Can't find metadata type `{type}`.") |>
+      cli::cli_abort(call = error_call)   
   }
 }
