@@ -5,13 +5,12 @@ check_queue <- function(.query, wait = FALSE){
   # process supplied object
   if(.query$status == "incomplete"){
     download_response <- c(list(type = .query$type),
-                           check_occurrence_status(.query))
-    class(download_response) <- "computed_query"
+                           check_occurrence_status(.query)) |>
+      structure(class = "computed_query")
     if(wait){
-      download_response <- c(list(type = .query$type),
-                             check_queue_loop(.query))
-      class(download_response) <- "computed_query"
-      download_response
+      c(list(type = .query$type),
+        check_queue_loop(.query)) |>
+        structure(class = "computed_query")
     }else{
       download_response
     }
@@ -21,8 +20,6 @@ check_queue <- function(.query, wait = FALSE){
 }
 
 #' Internal function to check queue status, with rate limiting
-#' @importFrom purrr rate_delay
-#' @importFrom purrr rate_sleep
 #' @noRd
 #' @keywords Internal
 check_queue_loop <- function(.query){
@@ -30,9 +27,10 @@ check_queue_loop <- function(.query){
   current_queue <- .query$queue_size
   continue <- TRUE
   iter <- 1
-  verbose <- pour("package", "verbose", .pkg = "galah")
+  verbose <- potions::pour("package", "verbose", .pkg = "galah")
   if(verbose){
-    inform(glue("Current queue length: {current_queue}"))
+    position <- glue::glue("Current queue length: {current_queue}")
+    cli::cli_text(position)
   }
   while(continue == TRUE){
     .query <- check_occurrence_status(.query)
@@ -40,13 +38,16 @@ check_queue_loop <- function(.query){
     if(continue){    
       iter <- iter + 1
       if(iter > 99){
-        inform(c("No data were returned after 100 tries.", 
-                 i = "If you have saved this output using e.g. `x <- collect(.query)`,", 
-                 i = "you can try again later using `collect(x)`"))
+        cli::cli({
+          cli::cli_text("No data were returned after 100 tries.")
+          c(i = "If you have saved this output using e.g. `x <- collect(.query)`,", 
+            i = "you can try again later using `collect(x)`") |>
+          cli::cli_bullets()
+        })
         return(.query)     
       }else{
         current_queue <- check_queue_size(.query, current_queue)
-        rate_sleep(rate_object, quiet = verbose)
+        purrr::rate_sleep(rate_object, quiet = verbose)
       }
     }else{
       return(.query)
@@ -55,25 +56,24 @@ check_queue_loop <- function(.query){
 }
 
 #' Internal function for rate limiting
-#' @importFrom purrr rate_backoff
 #' @noRd
 #' @keywords Internal
 set_rate <- function(){
-  rate_backoff(pause_base = 0.5, 
-               pause_cap = 60, 
-               max_times = 100,
-               jitter = FALSE)
+  purrr::rate_backoff(pause_base = 0.5, 
+                      pause_cap = 60, 
+                      max_times = 100,
+                      jitter = FALSE)
 }
 
 #' Internal function to check queue size
 #' @noRd
 #' @keywords Internal
 check_queue_size <- function(.query, current_queue){
-  verbose <- pour("package", "verbose", .pkg = "galah")
+  verbose <- potions::pour("package", "verbose", .pkg = "galah")
   if(.query$queue_size < current_queue & .query$queue_size > 0){
     current_queue <- .query$queue_size
     if(verbose){
-      inform(glue("Queue length: {current_queue}"))
+      cli::cli_text("Queue length: {current_queue}")
     }
   }else{
     if(verbose){cat("-")}
