@@ -16,7 +16,7 @@
 #' @param ... a profile name. Should be a `string` - the name or abbreviation 
 #'    of a data quality profile to apply to the query. Valid values can be seen 
 #'    using `show_all(profiles)`
-#' @return An updated `data_request` with a completed `data_profile` slot.
+#' @return An updated `data_request` with a completed `apply_profile` slot.
 #' @seealso [show_all()] and [search_all()] to look up available data profiles. 
 #' [filter.data_request()] can be used for more bespoke editing of individual data 
 #' profile filters.
@@ -29,27 +29,27 @@
 #'   apply_profile(ALA) |>
 #'   atlas_counts()
 #' }
-#' @importFrom rlang enquos
 #' @export
 apply_profile <- function(.data, ...){
-  dots <- enquos(..., .ignore_empty = "all")
+  dots <- rlang::enquos(..., .ignore_empty = "all")
   result <- parse_quosures_basic(dots) |>
-    pluck(!!!list(1)) |>
+    purrr::pluck(!!!list(1)) |>
     parse_profile()
-  update_data_request(.data, data_profile = result)
+  update_request_object(.data,
+                        apply_profile = result)
 }
 
 #' @rdname apply_profile
-#' @importFrom rlang enquos
 #' @export
 galah_apply_profile <- function(...){
-  dots <- enquos(..., .ignore_empty = "all") |>
+  dots <- rlang::enquos(..., .ignore_empty = "all") |>
     detect_request_object()
   switch(class(dots[[1]])[1],
          "data_request" = {
            result <- parse_quosures_basic(dots[-1]) |>
              parse_profile()
-           update_data_request(dots[[1]], data_profile = result)
+           update_request_object(dots[[1]],
+                                 apply_profile = result)
          },
          {
            parse_quosures_basic(dots) |>
@@ -58,19 +58,16 @@ galah_apply_profile <- function(...){
 }
 
 #' Internal parsing of `profile` args
-#' @importFrom glue glue
-#' @importFrom rlang abort
 #' @noRd
 #' @keywords Internal
-parse_profile <- function(dot_names, error_call = caller_env()) {
+parse_profile <- function(dot_names,
+                          error_call = rlang::caller_env()) {
   n_args <- length(dot_names)
   if (n_args > 0) {
     if (n_args > 1) {
-      bullets <- c(
-        "Too many data profiles supplied.",
-        x = glue("`galah_apply_profile()` accepts one profile argument, not {n_args}.")
-      )
-      abort(bullets, call = error_call)
+      c("Too many data profiles supplied.",
+        x = "`galah_apply_profile()` accepts one profile argument, not {n_args}.") |>
+      cli::cli_abort(call = error_call)
     }else{
       as.character(dot_names)
     }
