@@ -1,13 +1,5 @@
 #' @rdname geolocate
 #' @order 4
-#' @importFrom glue glue
-#' @importFrom rlang abort
-#' @importFrom rlang caller_env
-#' @importFrom rlang try_fetch
-#' @importFrom sf st_as_sfc 
-#' @importFrom sf st_bbox 
-#' @importFrom sf st_crs
-#' @importFrom sf st_is_valid 
 #' @export
 galah_bbox <- function(...) {
 
@@ -39,43 +31,45 @@ galah_bbox <- function(...) {
     unrecognised_class <- class(query)
     bullets <- c(
       "`galah_bbox` input must be an sf object, data.frame or tibble.",
-      x = glue("Can't use object of class '{unrecognised_class}'.")
-    )
+      x = "Can't use object of class '{unrecognised_class}'.")
     if (inherits(query, "character")) {
       suggest <- c(
         i = "Did you mean to use `galah_polygon`?"
       )
-      abort(c(bullets, suggest), call = caller_env())
+      cli::cli_abort(c(bullets, suggest),
+                     call = rlang::caller_env())
     } else {
-      abort(bullets, call = caller_env())
+      cli::cli_abort(bullets,
+                     call = rlang::caller_env())
     }
   }
 
   # handle shapefiles
-  if (inherits(query, "XY")) query <- st_as_sfc(query)
+  if (inherits(query, "XY")) query <- sf::st_as_sfc(query)
 
   # validate spatial objects & coordinates
   if (!inherits(query, c("sf", "sfc"))) {
     if(inherits(query, c("tbl", "data.frame"))) {
       check_col_names(query)
       query <- check_n_rows(query)
-      query <- st_bbox(c(xmin = query$xmin,
+      query <- sf::st_bbox(c(xmin = query$xmin,
                          xmax = query$xmax,
                          ymin = query$ymin,
                          ymax = query$ymax),
-                       crs = st_crs("WGS84"))
+                       crs = sf::st_crs("WGS84"))
     }
     log <- NULL # see `log` to read any warnings that may have been silenced
-    valid <- try_fetch( # prevent warnings
+    valid <- rlang::try_fetch( # prevent warnings
       query |>
-        st_as_sfc() |>
-        st_is_valid(), warning = function(cnd) {
+        sf::st_as_sfc() |>
+        sf::st_is_valid(), warning = function(cnd) {
           log <<- cnd
           ""
         })
   } 
   else {
-    valid <- query |> st_is_valid()
+    valid <- query |> 
+      sf::st_is_valid()
   }
   
   if (valid != TRUE) {
@@ -83,16 +77,20 @@ galah_bbox <- function(...) {
       "Invalid spatial object or WKT detected.",
       i = "Check that the spatial feature or bounding box in `galah_bbox` is correct."
     )
-    abort(bullets, call = caller_env())
+    cli::cli_abort(bullets, call = rlang::caller_env())
   } else {
-    if (inherits(query, c("tbl", "data.frame", "bbox")) && !inherits(query, c("sf", "sfc"))) {
+    if (inherits(query, c("tbl", "data.frame", "bbox")) && 
+        !inherits(query, c("sf", "sfc"))) {
       bbox_coords <- round(query, 5)
-      query <- query |> st_as_sfc(crs = st_crs("WGS84"))
+      query <- query |> 
+        sf::st_as_sfc(crs = sf::st_crs("WGS84"))
     } else {
       if (inherits(query, c("sf", "sfc"))) {
-        query <- query |> st_bbox(crs = st_crs("WGS84"))
+        query <- query |> 
+          sf::st_bbox(crs = sf::st_crs("WGS84"))
         bbox_coords <- round(query, 5)
-        query <- query |> st_as_sfc(crs = st_crs("WGS84")) # FIXME: should we define the projection?
+        query <- query |> 
+          sf::st_as_sfc(crs = sf::st_crs("WGS84")) # FIXME: should we define the projection?
       }
     }
   }
@@ -100,10 +98,12 @@ galah_bbox <- function(...) {
   # currently a bug where the ALA doesn't accept some polygons
   # to avoid any issues, any polygons are converted to multipolygons
   if (inherits(query, "sf") || inherits(query, "sfc")) {
-    inform(glue("
-             Data returned for bounding box:
-             xmin = {bbox_coords$xmin} xmax = {bbox_coords$xmax} \\
-             ymin = {bbox_coords$ymin} ymax = {bbox_coords$ymax}"))
+    cli::cli({
+      cli::cli_text("Data returned for bounding box:")
+      c("xmin = {bbox_coords$xmin} xmax = {bbox_coords$xmax}",
+        "ymin = {bbox_coords$ymin} ymax = {bbox_coords$ymax}") |>
+      cli::cli_bullets()
+    })
     out_query <- build_wkt(query)
   }
 
@@ -113,14 +113,12 @@ galah_bbox <- function(...) {
   if(is.null(dr)){
     out_query
   }else{
-    update_data_request(dr, geolocate = out_query)
+    update_request_object(dr,
+                          geolocate = out_query)
   }
 }
 
 #' Internal function to `galah_bbox`
-#' @importFrom glue glue
-#' @importFrom rlang warn
-#' @importFrom tibble tibble
 #' @noRd
 #' @keywords Internal
 check_n_rows <- function(tibble) {
@@ -131,25 +129,21 @@ check_n_rows <- function(tibble) {
       ignored_rows <- paste(2:(nrow(tibble)))
       bullets <- c(
         "More than 1 set of coordinates supplied to `galah_bbox`.",
-        "*" = glue("Using first row, ignoring row(s) {ignored_rows}.")
-      )
-      warn(bullets)
+        "*" = "Using first row, ignoring row(s) {ignored_rows}.")
+      cli::cli_warn(bullets)
       tibble <- tibble[1, ]
     }else{
       tibble <- tibble
     }
   }
-  
   return(tibble)
 }
 
 #' Internal function to `galah_bbox`
-#' @importFrom glue glue
-#' @importFrom rlang abort
-#' @importFrom tibble tibble
 #' @noRd
 #' @keywords Internal
-check_col_names <- function(tibble, error_call = caller_env()) {
+check_col_names <- function(tibble,
+                            error_call = rlang::caller_env()) {
   valid_col_names <- c("xmin", "xmax", "ymin", "ymax")
   if (!identical(sort(names(tibble)), sort(valid_col_names))) {
     col_names <- names(tibble[!names(tibble) %in% valid_col_names])
@@ -159,8 +153,7 @@ check_col_names <- function(tibble, error_call = caller_env()) {
     bullets <- c(
       "Incorrect column names supplied to `galah_bbox`.",
       i = "Column names must be: 'xmin', 'xmax', 'ymin', 'ymax'.",
-      x = glue("Unrecognised column name(s): '{col_names}'.")
-    )
-    abort(bullets, call = error_call)
+      x = "Unrecognised column name(s): '{col_names}'.")
+    cli::cli_abort(bullets, call = error_call)
   }
 }
