@@ -1,12 +1,15 @@
 # set verbose to off
 galah_config(verbose = FALSE, run_checks = FALSE)
 
+skip_message <- "French APIs disabled at source"
+
 test_that("swapping to atlas = France works", {
   expect_message(galah_config(atlas = "France"))
 })
 
 test_that("show_all(fields) works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- show_all(fields) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -16,6 +19,7 @@ test_that("show_all(fields) works for France", {
 
 test_that("show_all(collections) works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- show_all(collections, limit = 10) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -25,6 +29,7 @@ test_that("show_all(collections) works for France", {
 
 test_that("show_all(datasets) works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- show_all(datasets, limit = 10) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -34,6 +39,7 @@ test_that("show_all(datasets) works for France", {
 
 test_that("show_all(providers) works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- show_all(providers, limit = 10) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -42,11 +48,14 @@ test_that("show_all(providers) works for France", {
 })
 
 test_that("show_all(reasons) fails for France", {
+  skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   expect_error(show_all(reasons))
 })
 
 test_that("show_all(assertions) works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- show_all(assertions) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -55,15 +64,20 @@ test_that("show_all(assertions) works for France", {
 })
 
 test_that("show_all(profiles) fails for France", {
+  skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   expect_error(show_all(profiles))
 })
 
 test_that("show_all(lists) fails for France", {
+  skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   expect_error(show_all(lists))
 })
 
 test_that("search_all(fields) works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- search_all(fields, "year") |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -73,6 +87,7 @@ test_that("search_all(fields) works for France", {
 
 test_that("search_all(taxa) works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- search_all(taxa, "Vulpes vulpes") |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -82,6 +97,7 @@ test_that("search_all(taxa) works for France", {
 
 test_that("show_values works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- search_fields("basisOfRecord") |> 
       show_values() |>
     try(silent = TRUE)
@@ -91,6 +107,7 @@ test_that("show_values works for France", {
 
 test_that("atlas_counts works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- atlas_counts() |>
     pull(count) |>
     try(silent = TRUE)
@@ -100,6 +117,7 @@ test_that("atlas_counts works for France", {
 
 test_that("atlas_counts works with type = 'species' for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   x <- atlas_counts(type = "species") |>
     pull(count) |>
     try(silent = TRUE)
@@ -109,6 +127,7 @@ test_that("atlas_counts works with type = 'species' for France", {
 
 test_that("atlas_counts works with galah_identify for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   result <- galah_call() |>
     identify("Mammalia") |>
     count() |>
@@ -128,6 +147,7 @@ test_that("atlas_counts works with galah_identify for France", {
 
 test_that("atlas_counts works with group_by for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   result <- galah_call() |>
     filter(year >= 2018) |>
     group_by(year) |>
@@ -141,6 +161,7 @@ test_that("atlas_counts works with group_by for France", {
 
 test_that("atlas_species works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   galah_config(email = "ala4r@ala.org.au")
   x <- galah_call(type = "species") |>
     identify("Lagomorpha") |>
@@ -155,6 +176,7 @@ test_that("atlas_species works for France", {
 
 test_that("atlas_occurrences works for France", {
   skip_if_offline(); skip_on_ci()
+  skip(skip_message)
   galah_config(atlas = "France",
                email = "ala4r@ala.org.au")
   base_query <- galah_call() |>
@@ -187,4 +209,6 @@ test_that("atlas_occurrences works for France", {
   unlink("temp", recursive = TRUE)
 })
 
-galah_config(atlas = "Australia")
+quiet_config <- purrr::quietly(galah_config)
+quiet_config(atlas = "Australia")
+rm(quiet_config, skip_message)
\ No newline at end of file
